@@ -5,9 +5,12 @@ use warnings;
 # Import :
 use BlankOnDev::DataDev;
 use BlankOnDev::Version;
+use BlankOnDev::Rilis;
+use BlankOnDev::Form;
+use BlankOnDev::Form::github;
 
 # Version :
-our $VERSION = '0.1003';
+our $VERSION = '0.1004';
 
 # Subroutine for check Home Dir :
 # ------------------------------------------------------------------------
@@ -42,58 +45,29 @@ sub check_dir_boidev {
             $result = 1;
         }
     }
-
     return $result;
 }
-
-# Subroutine for list blankon release :
+# Suboutine for Form :
 # ------------------------------------------------------------------------
-sub list_rilis {
-    my %data = ();
-    $data{'tambora'} = '10';
-    $data{'uluwatu'} = '11';
-    return \%data;
-}
+sub FORM {
+    my ($self, $form, $data_config) = @_;
 
-# Subroutine for form blankon release :
-# ------------------------------------------------------------------------
-sub form_boi_rilis {
-    my $num_data_rilis;
-    my %data = ();
-    my $boi_rilis = 'tambora';
-    my $status = 0;
-    print "\n";
-    print "Choose rilis \n";
-    print "---" x 15 . "\n";
-#    my $daftar_rilis = list_rilis();
-#    my $num = 0;
-#    my %choose_rilis = ();
-#    while (my ($key, $value) = each %{$daftar_rilis}) {
-#        my $num_rilis = $num + 1;
-#        $choose_rilis{$num_rilis} = $key;
-#        print "$num_rilis. $key\n";
-#        $num++;
-#    }
-    print "1. Tambora\n";
-    print "2. Uluwatu\n";
-    print "Enter number choice : ";
-    chomp($num_data_rilis = <STDIN>);
-    if ($num_data_rilis ne '' and $num_data_rilis eq '1') {
-        $boi_rilis = 'tambora';
-        $status = 1;
-    } elsif ($num_data_rilis eq 2) {
-        $boi_rilis = 'uluwatu';
-        $status = 1;
+    my $result = '';
+    my $switch = {
+        'timezone' => 'form_timezone',
+        'rilis' => 'form_boi_rilis',
+        'name' => 'form_name',
+        'email-git' => 'form_email_git',
+        'email-gpg' => 'form_email_gpg',
+        'passph-gpg' => 'form_passphrase_gpg',
+    };
+
+    # Check Form :
+    if (exists $switch->{$form}) {
+        my $subr = $switch->{$form};
+        $result = BlankOnDev::Form->$subr($data_config);
     }
-    else {
-        $boi_rilis = 'tambora';
-        $status = 1;
-    }
-
-    $data{'result'} = $status;
-    $data{'data'} = $boi_rilis;
-
-    return \%data;
+    return $result;
 }
 
 # Subroutine for option help.
@@ -118,7 +92,7 @@ sub usage {
     print "\n";
 
     print "For USAGE : boidev <OPTIONS1>\n";
-    printf("  %-20s %s\n", "prepare", "Mempersiapkan sistem sebelum melakukan aktiftas pemaket");
+    printf("  %-20s %s\n", "mig_prepare", "Mempersiapkan sistem sebelum melakukan aktifitas Migrasi Repo");
     printf("  %-20s %s\n", "gpg-genkey", "Untuk generate key GnuPG");
     printf("  %-20s %s\n", "gpg-auth", "Untuk melihat name, email dan passphrase generate key");
     printf("  %-20s %s\n", "gpg-auth-dec", "Untuk melihat name, email dan passphrase yang tidak diencode");
@@ -126,6 +100,7 @@ sub usage {
     printf("  %-20s %s\n", "bzr2git", "Untuk mengambil data Repository dari Bazaar Server dan dimigrasi ke GitHub");
     printf("  %-20s %s\n", "list-cfg", "Untuk melihat konfigurasi yang sudah dilakukan");
     printf("  %-20s %s\n", "list-file", "Untuk melihat file configurasi konfigurasi yang sudah ada");
+    printf("  %-20s %s\n", "rilis", "Untuk mengganti nama rilis yang aktif.");
     print "\n";
 
     print "For USAGE : boidev bzr2git <OPTIONS2> \n";
@@ -143,7 +118,7 @@ sub usage {
     usage_bzr2git_addpkgfile();
     print "\n";
 
-    print "For USAGE : boidev bzr2git list-pkg <INPUT> \n";
+    print "For USAGE : boidev bzr2git list-pkg <OPTIONS3> \n";
     print "---------" x 11 . "\n";
     usage_bzr2git_listpkg();
     print "\n";
@@ -173,9 +148,9 @@ sub usage {
     usage_bzr2git_branch();
     print "\n";
 
-    print "For USAGE : boidev bzr2git bzr-cvr <INPUT> \n";
+    print "For USAGE : boidev bzr2git bzr-cgit <INPUT> \n";
     print "---------" x 11 . "\n";
-    usage_bzr2git_bzrconvert();
+    usage_bzr2git_bzr_cgit();
     print "\n";
     exit 0;
 }
@@ -193,9 +168,10 @@ sub usage_bzr2git {
     printf("  %-20s %s\n", "list-pkg-group", "Untuk melihat daftar group paket yang sudah terdaftar dalam system aplikasi.");
     printf("  %-20s %s\n", "search-pkg", "untuk mencari data paket yang terdaftar pada system aplikasi");
     printf("  %-20s %s\n", "branch", "Untuk branch dari repo bazaar berdasarkan list paket yang tersimpan pada system aplikasi");
-    printf("  %-20s %s\n", "bzr-cvr", "Untuk convert repository bazaar ke github repository");
+    printf("  %-20s %s\n", "bzr-cgit", "Untuk convert repository bazaar ke github repository");
     printf("  %-20s %s\n", "git-push", "Untuk push ke git berdasarkan semua list paket yang tersimpan pada system aplikasi atau hanya 1 paket saja.");
     printf("  %-20s %s\n", "git-push-new", "Untuk push ke git tanpa convert dari Bazaar");
+    printf("  %-20s %s\n", "git-check", "Untuk mengecek repo di github, beserta informasi branch yang tersedia");
     printf("  %-20s %s\n", "re-branch", "Untuk branch paket yang ada pada bazaar server");
     printf("  %-20s %s\n", "re-gitpush", "Untuk Deploy ulang ke github");
 #    printf("  %-20s %s\n", "", "");
@@ -217,36 +193,68 @@ sub usage_bzr2git_addpkgfile {
     printf("  %-20s %s\n", "help", "Berisi help penggunaan command \"boidev bzr2git addpkg-file\".");
 }
 sub usage_bzr2git_listpkg {
-    printf("  %-20s %s\n", "[group_name]", "Nama group paket yang tersimpan dalam system.");
+    printf("  %-20s %s\n", "[group_name]", "berisi nama group paket yang tersimpan dalam system.");
+    printf("  %-20s %s\n", "all", "Untuk melihat daftar semua paket yang tersimpan dalam system.");
     printf("  %-20s %s\n", "help", "Berisi help penggunaan command \"boidev bzr2git list-pkg\".");
 }
 sub usage_bzr2git_renamepkg_group {
-    printf("  %-20s %s\n", "[name_of_group_packages]", "Nama paket group yang akan diubah");
+    printf("  %-20s %s\n", "[name_of_group_packages]", "berisi nama paket group yang akan diubah");
     printf("  %-20s %s\n", "help", "Berisi help penggunaan command \"boidev bzr2git rename-pkg-group\".");
 }
 sub usage_bzr2git_removepkg_group {
-    printf("  %-20s %s\n", "[name_of_group_packages]", "Nama group paket yang akan dihapus, kemudian di rename");
+    printf("  %-20s %s\n", "[name_of_group_packages]", "berisi nama group paket yang akan dihapus, kemudian di rename");
     printf("  %-20s %s\n", "help", "Berisi help penggunaan command \"boidev bzr2git remove-pkg-group\".");
 }
 sub usage_bzr2git_removepkg {
-    printf("  %-20s %s\n", "[name_packages]", "Nama paket yang akan dihapus dari system aplikasi.");
-    printf("  %-20s %s\n", "[name_of_group_packages]", "Menghapus paket dari system aplikasi berdasarkan nama group paket");
+    printf("  %-20s %s\n", "[name_packages]", "berisi nama paket yang akan dihapus dari system aplikasi.");
+    printf("  %-20s %s\n", "[name_of_group_packages]", "untuk menghapus paket dari system aplikasi berdasarkan nama group paket");
     printf("  %-20s %s\n", "help", "Berisi help penggunaan command \"boidev bzr2git remove-pkg\".");
 }
 sub usage_bzr2git_searchpkg {
-    printf("  %-20s %s\n", "[name_of_packages]", "Nama paket yang akan dicari.");
+    printf("  %-20s %s\n", "[name_of_packages]", "berisi nama paket yang akan dicari.");
     printf("  %-20s %s\n", "help", "Berisi help penggunaan command \"boidev bzr2git search-pkg\".");
 }
 sub usage_bzr2git_branch {
-    printf("  %-20s %s\n", "[name_of_packages]", "Nama paket yang akan didownload melalui \"bzr branch\".");
-    printf("  %-20s %s\n", "[name_of_group_packages]", "nama group paket untuk mengdownload semua paket yang terkait dengan group melalui \"bzr branch\".");
+    printf("  %-20s %s\n", "[name_of_packages]", "berisi nama paket yang akan didownload melalui \"bzr branch\".");
+    printf("  %-20s %s\n", "[name_of_group_packages]", "berisi nama group paket untuk mengdownload semua paket yang terkait dengan group melalui \"bzr branch\".");
     printf("  %-20s %s\n", "help", "Berisi help penggunaan command \"boidev bzr2git search-pkg\".");
 }
-sub usage_bzr2git_bzrconvert {
-    printf("  %-20s %s\n", "[name_of_packages]", "Nama paket yang akan dikonversi ke repo github");
-    printf("  %-20s %s\n", "[name_of_group_packages]", "Nama group paket untuk meng-konversi semua paket yang terkait dengan group");
+sub usage_bzr2git_bzr_cgit {
+    printf("  %-20s %s\n", "[name_of_packages]", "berisi nama paket yang akan dikonversi ke repo github");
+    printf("  %-20s %s\n", "[name_of_group_packages]", "berisi nama group paket untuk meng-konversi semua paket yang terkait dengan group");
     printf("  %-20s %s\n", "", "ke format repositori github");
-    printf("  %-20s %s\n", "help", "Berisi help penggunaan command \"boidev bzr2git search-pkg\".");
+    printf("  %-20s %s\n", "help", "Berisi help penggunaan command \"boidev bzr2git bzr-cgit\".");
+}
+sub usage_bzr2git_gitpush {
+    printf("  %-20s %s\n", "[name_of_packages]", "berisi nama paket yang akan di dorong ke github");
+    printf("  %-20s %s\n", "[name_of_group_packages]", "berisi nama group paket untuk mendorong semua paket yang terkait dengan group");
+    printf("  %-20s %s\n", "", "ke repositori github");
+    printf("  %-20s %s\n", "help", "Berisi help penggunaan command \"boidev bzr2git git-push\".");
+}
+sub usage_bzr2git_gitpush_new {
+    printf("  %-20s %s\n", "[name_of_packages]", "berisi nama paket yang akan di dorong ke github tanpa konveri dari format bazaar ke github");
+    printf("  %-20s %s\n", "[name_of_group_packages]", "berisi nama group paket untuk mendorong semua paket yang terkait dengan group");
+    printf("  %-20s %s\n", "", "ke repositori github tanpa konveri dari format bazaar ke github");
+    printf("  %-20s %s\n", "help", "Berisi help penggunaan command \"boidev bzr2git git-push\".");
+}
+sub usage_bzr2git_git_check {
+    printf("  %-20s %s\n", "[name_of_packages]", "berisi nama paket yang akan dicek dalam repositori github");
+    printf("  %-20s %s\n", "[name_of_group_packages]", "berisi nama group paket untuk mengecek semua paket yang terkait dengan group");
+    printf("  %-20s %s\n", "", "yang berada dalam repositori github.");
+    printf("  %-20s %s\n", "help", "Berisi help penggunaan command \"boidev bzr2git git-push\".");
+}
+sub usage_bzr2git_reBranch {
+    printf("  %-20s %s\n", "[name_of_packages]", "berisi nama paket yang akan dibranch ulang dari server repositori bazaar");
+    printf("  %-20s %s\n", "[name_of_group_packages]", "berisi nama group paket untuk branch ulang semua paket yang terkait dengan group");
+    printf("  %-20s %s\n", "", "yang berada dalam repositori bazaar.");
+    printf("  %-20s %s\n", "help", "Berisi help penggunaan command \"boidev bzr2git git-push\".");
+}
+sub usage_bzr2git_reGitpush {
+    printf("  %-20s %s\n", "[name_of_packages]", "berisi nama paket yang akan dorong ulang ke github, ");
+    printf("  %-20s %s\n", "", "untuk dilakukan perbaikan terhadap proses push yang salah");
+    printf("  %-20s %s\n", "[name_of_group_packages]", "berisi nama group paket untuk mendorong ulang semua paket yang terkait dengan group");
+    printf("  %-20s %s\n", "", "ke repositori github, untuk dilakukan perbaikan terhadap proses push yang salah");
+    printf("  %-20s %s\n", "help", "Berisi help penggunaan command \"boidev bzr2git git-push\".");
 }
 
 # For Help in list pkg :
