@@ -14,13 +14,14 @@ use BlankOnDev::Utils::file;
 use BlankOnDev::enkripsi;
 use BlankOnDev::DataDev;
 use BlankOnDev::config::save;
-use BlankOnDev::Migration::bazaar2GitHub::tmp_cfg;
+use BlankOnDev::Rilis;
+use BlankOnDev::command;
 
 # Version :
-our $VERSION = '0.1003';
+our $VERSION = '0.1004';
 
 # Our vars :
-our $rilis = '';
+our $gencfg = {};
 our $allconfig = {};
 our $filename_cfg = '';
 our $dirdev_cfg = '';
@@ -34,7 +35,6 @@ our $r_gitcfg = 0;
 our $r_gpgcfg = 0;
 our $r_config = {};
 our $time_zone = 'Asia/Makassar';
-our $_setup = {};
 
 # Subroutine for option "prepare" :
 # ------------------------------------------------------------------------
@@ -58,7 +58,6 @@ sub _prepare {
             'prepare' => $prepareCfg,
             'build' => {
                 'rilis' => $rilisCfg,
-                'gpg' => $data_gpg,
             },
             'bzr' => exists $bzrCfg->{'url'} ? $bzrCfg : $allconfig->{'bzr'},
             'git' => exists $gitCfg->{'url'} ? $gitCfg : $allconfig->{'git'},
@@ -70,6 +69,61 @@ sub _prepare {
 
     BlankOnDev::config::save->prepare($data);
 }
+# Subroutine for general config :
+# ------------------------------------------------------------------------
+sub _general_config {
+    # Preare general conig :
+    my $data_setup = data_setup();
+    my $dir_dev = $data_setup->{'dir_dev'};
+    my $prefix_file_cfg = $data_setup->{'prefix_flcfg'};
+    my $ext_flcfg = $data_setup->{'fileCfg_ext'};
+    my $file_cfg = 'general'.$ext_flcfg;
+
+    # Get current Configure :
+    my $curr_timezone = $gencfg->{'timezone'};
+    my $curr_rilis = $gencfg->{'rilis'};
+    my $curr_name = $gencfg->{'data'}->{'name'};
+    my $curr_email_git = $gencfg->{'data'}->{'email-git'};
+    my $curr_email_gpg = $gencfg->{'data'}->{'email-gpg'};
+    my $curr_passph_gpg = $gencfg->{'data'}->{'passph-gpg'};
+
+    # For Timezone :
+    my $data_timezone = BlankOnDev->FORM('timezone', $curr_timezone);
+
+    # Get data release :
+    my $data_rilis = BlankOnDev::Rilis::data();
+    my $form_rilis = BlankOnDev->FORM('rilis');
+    my $boi_rilis;
+    if ($form_rilis->{'result'} == 1) {
+        $boi_rilis = $form_rilis->{'data'};
+    } else {
+        $boi_rilis = $data_rilis->{'10'}->{'name'};
+    }
+    my $data_name = BlankOnDev->FORM('name', $curr_name);
+    my $data_email_git = BlankOnDev->FORM('email-git', $curr_email_git);
+    my $data_email_gpg = BlankOnDev->FORM('email-gpg', $curr_email_gpg);
+    my $data_passph_gpg = BlankOnDev->FORM('passph-gpg', '');
+    $data_passph_gpg = enc_ggp_genkey($data_email_gpg, $data_passph_gpg);
+    BlankOnDev::Form::github->form_config_github($data_name, $data_email_git);
+
+    my $new_dataCfg = Hash::MultiValue->new();
+    $new_dataCfg->add('name' => $data_name);
+    $new_dataCfg->add('email-git' => $data_email_git);
+    $new_dataCfg->add('email-gpg' => $data_email_gpg);
+    $new_dataCfg->add('passph-gpg' => $data_passph_gpg);
+    my $result_dataCfg = $new_dataCfg->as_hashref;
+
+    my $new_genCfg = Hash::MultiValue->new();
+    $new_genCfg->add('timezone' => $data_timezone);
+    $new_genCfg->add('rilis' => $boi_rilis);
+    $new_genCfg->add('data' => $result_dataCfg);
+    my $result_cfg = $new_genCfg->as_hashref;
+
+    # Save new config :
+    BlankOnDev::config::save->save_to_file($file_cfg, $dir_dev, $result_cfg);
+
+    print "\n";
+}
 # Subroutine for option "gpg-gen-key :
 # ------------------------------------------------------------------------
 sub _gpg_genkey {
@@ -79,46 +133,24 @@ sub _gpg_genkey {
     my $prefix_flcfg = $data_setup->{'prefix_flcfg'};
     my $file_cfg_ext = $data_setup->{'fileCfg_ext'};
 
-    # Get All Data Config :
-    my $prepare = $allconfig->{'prepare'};
-    my $build = $allconfig->{'build'};
-    my $build_rilis = $build->{'rilis'};
-    my $build_pgp = $build->{'pgp'};
-    my $bzr = $allconfig->{'bzr'};
-    my $git = $allconfig->{'git'};
-    my $pkg = $allconfig->{'pkg'};
-
-    # Enter Rilis :
-#    boi_rilis();
+    # Get current general config :
+    my $data_gencfg = $gencfg->{'data'};
+    my $curr_name = $data_gencfg->{'name'};
+    my $curr_emailgit = $data_gencfg->{'email-git'};
+    my $curr_emailgpg = $data_gencfg->{'email-gpg'};
+    my $curr_passph = $data_gencfg->{'passph-gpg'};
+    $curr_passph = dec_gpg_genkey($curr_emailgpg, $curr_passph);
+    my $newData_cfg = $data_gencfg;
 
     # Check File Config :
-    my $file_cfg = $prefix_flcfg.$rilisCfg.$file_cfg_ext;
+    my $file_cfg = 'general'.$file_cfg_ext;
     my $loc_file = $dir_dev.$file_cfg;
     $filename_cfg = $file_cfg;
     $dirdev_cfg = $dir_dev;
     print "Filename : $file_cfg\n";
     if (-e $loc_file) {
         # GPG Generate Key :
-        my $gpg_cfg = gpg_config();
-
-        # Define hash for new data :
-        my $data = {
-            'r_config' => {
-                'timezone' => $time_zone,
-                'prepare' => $prepare,
-                'build'   => {
-                    'rilis' => $build_rilis,
-                    'gpg'   => $gpg_cfg->{'gpg'},
-                },
-                'bzr' => $bzr,
-                'git' => $git,
-                'pkg' => $pkg,
-            },
-            'filename' => $filename_cfg,
-            'dir_dev' => $dirdev_cfg
-        };
-
-        BlankOnDev::config::save->gpg_genkey($data);
+        gpg_config($curr_name, $curr_emailgpg, $curr_passph);
     }
 }
 # Subroutine for get list gpg auth :
@@ -131,12 +163,10 @@ sub _gpg_auth {
     my $file_cfg_ext = $data_setup->{'fileCfg_ext'};
 
     # Get All Data Config :
-    my $build = $allconfig->{'build'};
-    my $build_rilis = $build->{'rilis'};
-    my $build_gpg = $build->{'gpg'};
-    my $name_gpg = $build_gpg->{'name'};
-    my $email_gpg = $build_gpg->{'email'};
-    my $passphrase_gpg = $build_gpg->{'passphrase'};
+    my $data_gencfg = $gencfg->{'data'};
+    my $name_gpg = $data_gencfg->{'name'};
+    my $email_gpg = $data_gencfg->{'email-gpg'};
+    my $passphrase_gpg = $data_gencfg->{'passph-gpg'};
 
     # Print Result :
     print "\n";
@@ -158,12 +188,10 @@ sub _gpg_auth_dec {
     my $file_cfg_ext = $data_setup->{'fileCfg_ext'};
 
     # Get All Data Config :
-    my $build = $allconfig->{'build'};
-    my $build_rilis = $build->{'rilis'};
-    my $build_gpg = $build->{'gpg'};
-    my $name_gpg = $build_gpg->{'name'};
-    my $email_gpg = $build_gpg->{'email'};
-    my $passphrase_gpg = $build_gpg->{'passphrase'};
+    my $data_gencfg = $gencfg->{'data'};
+    my $name_gpg = $data_gencfg->{'name'};
+    my $email_gpg = $data_gencfg->{'email-gpg'};
+    my $passphrase_gpg = $data_gencfg->{'passph-gpg'};
     my $thepassphrase = dec_gpg_genkey($email_gpg, $passphrase_gpg);
 
     # Print Result :
@@ -184,13 +212,13 @@ sub _list_cfg {
     my $prefix_flcfg = $data_setup->{'prefix_flcfg'};
     my $file_cfg_ext = $data_setup->{'fileCfg_ext'};
 
+    print Dumper $gencfg;
+    # General Configure :
+    my $data_cfg = $gencfg->{data};
+    my $name_cfg = $data_cfg->{'name'};
+    my $email_gpg = $data_cfg->{'email-gpg'};
+
     # Get Data current Configure :
-    my $prepare = $allconfig->{prepare};
-    my $build = $allconfig->{build};
-    my $build_rilis = $build->{'rilis'};
-    my $build_pgp = $build->{'gpg'};
-    my $pgp_name = $build_pgp->{'name'};
-    my $pgp_email = $build_pgp->{'email'};
     my $bzr = $allconfig->{bzr};
     my $bzr_url = $bzr->{'url'};
     my $git = $allconfig->{git};
@@ -206,8 +234,8 @@ sub _list_cfg {
     print "\n";
 
     print "PGP Configure :\n";
-    print "Name : $pgp_name\n";
-    print "Email : $pgp_email\n\n";
+    print "Name : $name_cfg\n";
+    print "Email : $email_gpg\n\n";
 
     print "URL Configure : \n";
     print "Bzr Branch : $bzr_url\n";
@@ -239,17 +267,45 @@ sub _list_file {
     my $i = 0;
     while ($i < scalar @files) {
         if ($files[$i] =~ m/\.config$/) {
+            if ($files[$i] =~ m/general/) {
+                printf("%-20s %s", "General Configure ", ": $files[$i]\n");
+            }
             if ($files[$i] =~ m/tambora/) {
-                print "Tambora : $files[$i]\n";
+                printf("%-20s %s", "Tambora ", ": $files[$i]\n");
             }
             if ($files[$i] =~ m/uluwatu/) {
-                print "Uluwatu : $files[$i]\n";
+                printf("%-20s %s", "Uluwatu ", ": $files[$i]\n");
             }
         }
         $i++;
     }
     print "\n";
 }
+# Subroutine for changes rilis active :
+# ------------------------------------------------------------------------
+sub _rilis {
+    # Prepare :
+    my $curr_rilis = $gencfg->{'rilis'};
+
+    # Form Rilis :
+    my $data_setup = data_setup();
+    my $dir_dev = $data_setup->{'dir_dev'};
+    my $ext_flcfg = $data_setup->{'fileCfg_ext'};
+    my $file_cfg = 'general'.$ext_flcfg;
+
+    # Action Form :
+    my $form_rilis = BlankOnDev->FORM('rilis', $curr_rilis);
+    my $boi_rilis;
+    if ($form_rilis->{'result'} == 1) {
+        $boi_rilis = $form_rilis->{'data'};
+    } else {
+        $boi_rilis = 'tambora';
+    }
+    $gencfg->{'rilis'} = $boi_rilis;
+
+    # Save new rilis :
+    BlankOnDev::config::save->save_to_file($file_cfg, $dir_dev, $gencfg);
+}
 # Subroutine for option "config" :
 # ------------------------------------------------------------------------
 sub config {
@@ -263,10 +319,26 @@ sub config {
     my $read_fileCfg;
     my $home_dir = $ENV{"HOME"};
 
+    # Get current general config :
+    my $curr_timezone = '';
+    my $data_gencfg = $gencfg->{'data'};
+    my $curr_name = $data_gencfg->{'name'};
+    my $curr_emailgit = $data_gencfg->{'email-git'};
+    my $curr_emailgpg = $data_gencfg->{'email-gpg'};
+    my $curr_passph = $data_gencfg->{'passph-gpg'};
+    $curr_passph = dec_gpg_genkey($curr_emailgpg, $curr_passph);
+    my $newData_cfg = $data_gencfg;
+
+    # Preare general conig :
+    my $data_setup = data_setup();
+    my $dir_dev = $data_setup->{'dir_dev'};
+    my $prefix_file_cfg = $data_setup->{'prefix_flcfg'};
+    my $ext_flcfg = $data_setup->{'fileCfg_ext'};
+    my $file_cfg = 'general'.$ext_flcfg;
 
     # Get Command :
     # ----------------------------------------------------------------
-    my $get_cmd = cmd_list();
+    my $get_cmd = BlankOnDev::command::github();
     my $getGit_cmd = $get_cmd->{'git'};
     my $gitCmd_name = $getGit_cmd->{'cfg-name'};
     my $gitCmd_email = $getGit_cmd->{'cfg-email'};
@@ -277,12 +349,7 @@ sub config {
 
     # For TimeZone :
     # ----------------------------------------------------------------
-    print "Example name TimeZone \"Asia/Makassar\" \n";
-    print "Set your timezone name : ";
-    chomp($timezone = <STDIN>);
-    if ($timezone ne '') {
-        $time_zone = $timezone;
-    }
+    $time_zone = BlankOnDev->FORM('timezone', $curr_timezone);
 
     # For GitHub Configure
     # ------------------------------------------------------------------------
@@ -292,32 +359,39 @@ sub config {
         chomp($confirmation = <STDIN>);
         if ($confirmation eq 'y') {
 
-            $read_fileCfg = BlankOnDev::Utils::file->read($home_dir."/.gitconfig");
+            # Print FORM :
             my $name_git;
             my $email_git;
-            if ($read_fileCfg =~ m/(name)\s(\=)\s(.*)/) {
-                $name_git = $3;
-            }
-            if ($read_fileCfg =~ m/(email)\s(\=)\s(.*)/) {
-                $email_git = $3;
-            }
-
-            # Print FORM :
-            print "Enter your github fullname [$name_git] : ";
+            print "Enter your github fullname [$curr_name] : ";
             chomp($gitname = <STDIN>);
-            print "Enter your github email [$email_git] : ";
+            print "Enter your github email [$curr_emailgit] : ";
             chomp($gitemail = <STDIN>);
             if ($gitname eq '') {
-                $gitname = $name_git;
+                $gitname = $curr_name;
             }
             if ($gitemail eq '') {
-                $gitemail = $email_git;
+                $gitemail = $curr_emailgit;
             }
 
             if ($gitname ne '' and $gitemail ne '') {
                 system("$gitCmd_name \"$gitname\"");
                 system("$gitCmd_email \"$gitemail\"");
                 $r_gitset = 1;
+
+                # For Data config :
+                $newData_cfg = Hash::MultiValue->new(%{$data_gencfg});
+                $newData_cfg->set('name' => $gitname);
+                $newData_cfg->set('email-git' => $gitemail);
+                $newData_cfg = $newData_cfg->as_hashref;
+
+                # For Save New config :
+                my $saveCfg = Hash::MultiValue->new(%{$gencfg});
+                $saveCfg->set('data' => $newData_cfg);
+                my $result_cfg = $saveCfg->as_hashref;
+
+                # Save new config :
+                BlankOnDev::config::save->save_to_file($file_cfg, $dir_dev, $result_cfg);
+
             } else {
                 $r_gitset = 0;
                 print "git user.name or user.email not enter\n";
@@ -334,6 +408,20 @@ sub config {
             system("$gitCmd_name \"$gitname\"");
             system("$gitCmd_email \"$gitemail\"");
             $r_gitset = 1;
+
+            # For Data config :
+            $newData_cfg = Hash::MultiValue->new(%{$data_gencfg});
+            $newData_cfg->set('name' => $gitname);
+            $newData_cfg->set('email-git' => $gitemail);
+
+            # For Save New config :
+            my $saveCfg = Hash::MultiValue->new(%{$gencfg});
+            $saveCfg->set('data' => $newData_cfg);
+            my $result_cfg = $saveCfg->as_hashref;
+
+            # Save new config :
+            BlankOnDev::config::save->save_to_file($file_cfg, $dir_dev, $result_cfg);
+
         } else {
             $r_gitset = 0;
             print "git user.name or user.email not enter\n";
@@ -346,7 +434,7 @@ sub config {
     if ($read_fileCfg =~ m/(helper)\s(\=)\s(.*)/) {
         # For cache user and password git push :
         print "Cache user and password is activated\n";
-        print "You want to clear [y/n]: ";
+        print "You want to clear [y/n] : ";
         chomp($cache_auth = <STDIN>);
         if ($cache_auth eq 'y') {
 #            $read_fileCfg =~ s/^\[credential.*//g;
@@ -372,7 +460,7 @@ sub config {
     print "You want GnuPG Generate key [y/n] : ";
     chomp($gnupg_genkey = <STDIN>);
     if ($gnupg_genkey eq 'y') {
-        gpg_config();
+        gpg_config($curr_name, $curr_emailgpg, $curr_passph);
     }
 #    print Dumper $allconfig;
 }
@@ -386,24 +474,44 @@ sub data_setup {
 # Subroutine for Set name BlankOn Rilis :
 # ------------------------------------------------------------------------
 sub boi_rilis {
-    my $form_rilis = BlankOnDev::form_boi_rilis();
-    my $boi_rilis;
-    if ($form_rilis->{'result'} == 1) {
-        $boi_rilis = $form_rilis->{'data'};
+    my $data_setup = data_setup();
+    my $dir_dev = $data_setup->{'dir_dev'};
+    my $ext_flcfg = $data_setup->{'fileCfg_ext'};
+    my $file_cfg = 'general'.$ext_flcfg;
+
+    # Check Rilis Selection :
+    if ($gencfg->{'rilis'} eq '') {
+        my $form_rilis = BlankOnDev->FORM('rilis', '');
+        my $boi_rilis;
+        if ($form_rilis->{'result'} == 1) {
+            $boi_rilis = $form_rilis->{'data'};
+        } else {
+            $boi_rilis = 'tambora';
+        }
+        $rilisCfg = $boi_rilis;
+        $gencfg->{'rilis'} = $boi_rilis;
+
+        # Save new rilis :
+        BlankOnDev::config::save->save_to_file($file_cfg, $dir_dev, $gencfg);
     } else {
-        $boi_rilis = 'tambora';
+        $rilisCfg = $gencfg->{'rilis'};
     }
-    $rilisCfg = $boi_rilis;
 }
 # Subroutine for Encode passphrase GnuPG Generate Key :
 # ------------------------------------------------------------------------
 sub enc_ggp_genkey {
     my ($email, $passphrase) = @_;
-#    print "Input Email : $email\n";
-#    print "Input Passphrase : $passphrase\n";
+#    my $len_email = length $email;
+#    my $len_pass = length $passphrase;
+#    print "\n";
+#    print "In Enc\n";
+#    print "Input Email : $email [$len_email]\n";
+#    print "Input Passphrase : $passphrase [$len_pass]\n";
 
     my $plan_key = BlankOnDev::enkripsi->getKey_enc($email);
     my $encoder = BlankOnDev::enkripsi->Encoder($passphrase, $plan_key);
+#    print "Result Encoder : $encoder\n";
+#    print Dumper $plan_key;
 
     return $encoder;
 }
@@ -411,18 +519,24 @@ sub enc_ggp_genkey {
 # ------------------------------------------------------------------------
 sub dec_gpg_genkey {
     my ($email, $passphrase) = @_;
-#    print "Input Email : $email\n";
-#    print "Input Passphrase : $passphrase\n";
+#    my $len_email = length $email;
+#    my $len_pass = length $passphrase;
+#    print "\n";
+#    print "In Dec\n";
+#    print "Input Email : $email [$len_email]\n";
+#    print "Input Passphrase : $passphrase [$len_pass]\n";
 
     my $plan_key = BlankOnDev::enkripsi->getKey_enc($email);
     my $decoder = BlankOnDev::enkripsi->Decoder($passphrase, $plan_key);
-    $decoder =~ s/\|+//g;
+#    $decoder =~ s/\|+//g;
+#    print Dumper $plan_key;
 
     return $decoder;
 }
 # Subroutine for GNUpg configure :
 # ------------------------------------------------------------------------
 sub gpg_config {
+    my ($name, $email, $passph) = @_;
     # Define hash :
     my %data = ();
 
@@ -431,34 +545,19 @@ sub gpg_config {
     my $gpg_algo = '';
     my $gpg_name = '';
     my $gpg_email = '';
+    my $confirm_passph = '';
     my $gpg_passph = '';
     my $gpg_passph_enc = '';
+    my $curr_gpg_passph;
 
-    # Define scalar for current data :
-    my $curr_gpg_algo = '';
-    my $curr_gpg_name = '';
-    my $curr_gpg_email = '';
-    my $curr_gpg_passph = '';
-    my $curr_gpg_passph_dec = '';
-    my $currdt_gpg_name = '';
-    my $currdt_gpg_email = '';
-    my $currdt_gpg_passph = '';
-    my $currdt_gpg_passph_dec = '';
+    # Data Setup :
+    my $data_setup = data_setup();
+    my $dir_dev = $data_setup->{'dir_dev'};
+    my $ext_flcfg = $data_setup->{'fileCfg_ext'};
+    my $file_cfg = 'general'.$ext_flcfg;
 
-    # Read Current config ;
-    my $curren_cfg = $allconfig;
-    my $build_cfg = $allconfig->{'build'};
-    my $build_gpg = $build_cfg->{'gpg'};
-    if (exists $build_gpg->{'name'}) {
-        $curr_gpg_name = '['.$build_gpg->{'name'}.']' if $build_gpg->{'name'} ne '';
-        $curr_gpg_email = '['.$build_gpg->{'email'}.']' if $build_gpg->{'email'} ne '';
-        $curr_gpg_passph = '['.$build_gpg->{'passphrase'}.']' if $build_gpg->{'passphrase'} ne '';
-        $curr_gpg_passph_dec = $build_gpg->{'passphrase'} if $build_gpg->{'passphrase'} ne '';
-        $currdt_gpg_name = $build_gpg->{'name'} if $build_gpg->{'name'} ne '';
-        $currdt_gpg_email = $build_gpg->{'email'} if $build_gpg->{'email'} ne '';
-        $currdt_gpg_passph = $build_gpg->{'passphrase'} if $build_gpg->{'passphrase'} ne '';
-        $currdt_gpg_passph_dec = $build_gpg->{'passphrase'} if $build_gpg->{'passphrase'} ne '';
-    }
+    # Get current general config :
+    my $data_gencfg = $gencfg->{'data'};
 
     # Title Form :
     print "\n";
@@ -467,14 +566,6 @@ sub gpg_config {
     print "-----" x 15 . "\n";
     print "\n";
 
-    # Form Algorithm GnuPG :
-#    print "Choose Algorithm GnuPG : \n";
-#    print "1. RSA,\n";
-#    print "2. DSA,\n";
-#    if ($curr_gpg_algo ne '') {
-#        print "You have current GnuPG config on system = $curr_gpg_algo\n";
-#    }
-#    chomp($input_gpg_algo = <STDIN>);
     if ($input_gpg_algo eq '1') {
         $gpg_algo = 'RSA';
     } elsif ($input_gpg_algo eq '2') {
@@ -484,36 +575,45 @@ sub gpg_config {
     }
 
     # Form Name GnuPG generate key :
-    print "Enter Name $curr_gpg_name : ";
+    print "Enter Name [$name] : ";
     chomp($gpg_name = <STDIN>);
     if ($gpg_name eq '') {
-        $gpg_name = $currdt_gpg_name;
+        $gpg_name = $name;
     }
 
     # Form Email for GnuPG generate key :
-    print "Enter E-mail $curr_gpg_email : ";
+    print "Enter E-mail [$email] : ";
     chomp($gpg_email = <STDIN>);
     if ($gpg_email eq '') {
-        $gpg_email = $currdt_gpg_email;
+        $gpg_email = $email;
     }
 
     # From PassPhrase for GnuPG generate key :
-    print "Enter passphrase : ";
-    ReadMode('noecho');
-    $gpg_passph = ReadLine(0);
-    if ($gpg_passph eq '') {
-        if ($curr_gpg_passph eq '') {
-            $curr_gpg_passph = 'admin123';
-            print "Please enter your passphrase GnuPG !!!\n";
-            exit 0;
+    print "\n";
+    print "You want to enter different passphrase GnuPG ? [y or n] ";
+    chomp($confirm_passph = <STDIN>);
+    if ($confirm_passph eq 'y' or $confirm_passph eq 'Y') {
+        print "Enter passphrase : ";
+        ReadMode('noecho');
+        $gpg_passph = ReadLine(0);
+        $gpg_passph =~ s/\n//g;
+        if ($gpg_passph eq '') {
+            $gpg_passph_enc = enc_ggp_genkey($gpg_email, $passph);
+            $gpg_passph = $passph;
+        } else {
+            $gpg_passph_enc = enc_ggp_genkey($gpg_email, $gpg_passph);
         }
-        $gpg_passph_enc = enc_ggp_genkey($gpg_email, $currdt_gpg_passph);
-        $gpg_passph = $currdt_gpg_passph;
+        $r_gpgcfg = 1;
+        ReadMode 1;
+
+#        print "\n";
+#        print "ori passph gpg : $gpg_passph \n";
+#        print "Email for enc : $gpg_email\n";
+#        print "Enc passph gpg : $gpg_passph_enc \n";
     } else {
-        $gpg_passph_enc = enc_ggp_genkey($gpg_email, $gpg_passph);
+        $gpg_passph = $passph;
+        $gpg_passph_enc = enc_ggp_genkey($email, $passph);
     }
-    $r_gpgcfg = 1;
-    ReadMode 1;
 
     # Initialize GnuPG Module :
     my $gpg = GnuPG->new();
@@ -521,17 +621,29 @@ sub gpg_config {
 #        algo => $gpg_algo,
         name => $gpg_name,
         email => $gpg_email,
-        passphrase => $gpg_passph_enc,
+        passphrase => $gpg_passph,
     );
 
     # Place data :
     $data{'gpg'} = {
-        'alg' => $gpg_algo,
         'name' => $gpg_name,
         'email' => $gpg_email,
         'passphrase' => $gpg_passph_enc
     };
 
+    # Prepare Configure :
+    my $pre_cfg = Hash::MultiValue->new(%{$data_gencfg});
+    $pre_cfg->set('passph-gpg' => $gpg_passph_enc);
+    my $newData_cfg = $pre_cfg->as_hashref;
+
+    # Merge Configure :
+    my $merge_cfg = Hash::MultiValue->new(%{$gencfg});
+    $merge_cfg->set('data' => $newData_cfg);
+    my $result_cfg = $merge_cfg->as_hashref;
+
+    # Save configure :
+    BlankOnDev::config::save->save_to_file($file_cfg, $dir_dev, $result_cfg);
+
     # Return :
     $gpgCfg = \%data;
     return \%data;
@@ -606,9 +718,49 @@ sub git_config {
         $r_gitcfg = 1;
     }
 }
+# Subroutine for general config :
+# ------------------------------------------------------------------------
+sub read_gen_cfg {
+    my $data = '';
+    my $data_setup = data_setup();
+    my $dir_dev = $data_setup->{'dir_dev'};
+    my $ext_flcfg = $data_setup->{'fileCfg_ext'};
+    my $tmp_dir = $data_setup->{'dir_tmp'};
+
+    # For General Configure :
+    my $file_name = 'general'.$ext_flcfg;
+    my $loc_file = $dir_dev.$file_name;
+
+    # For format config :
+    my $format_config = format_general_config();
+
+    # For Dir Temp
+    unless (-d $tmp_dir) {
+        mkdir($tmp_dir);
+    }
+
+    # Check Dir config :
+    if (-d $dir_dev) {
+        # Check File general configure :
+        if (-e $loc_file) {
+            my $get_cfg = BlankOnDev::Utils::file->read($loc_file);
+            my $data_cfg = decode_json($get_cfg);
+            $data = $data_cfg;
+        } else {
+            BlankOnDev::Utils::file->create($file_name, $dir_dev, encode_json($format_config));
+            $data = $format_config;
+        }
+    } else {
+        mkdir($dir_dev);
+        BlankOnDev::Utils::file->create($file_name, $dir_dev, encode_json($format_config));
+        $data = $format_config;
+    }
+
+    $gencfg = $data;
+}
 # Subroutine for read config :
 # ------------------------------------------------------------------------
-sub read_config {
+sub read_config_bzr2git {
     my $data = '';
     my %data_pkg = ();
     my $data_setup = data_setup();
@@ -621,7 +773,19 @@ sub read_config {
 
     # For Release set :
     # ----------------------------------------------------------------
-    boi_rilis();
+    if (exists $ARGV[0] and $ARGV[0] ne 'config') {
+        boi_rilis() if $gencfg->{'rilis'} eq '';
+        $rilisCfg = $gencfg->{'rilis'} if $gencfg->{'rilis'} ne '';
+    } else {
+        $rilisCfg = $gencfg->{'rilis'};
+        boi_rilis() if $gencfg->{'rilis'} eq '';
+        $rilisCfg = $gencfg->{'rilis'} if $gencfg->{'rilis'} ne '';
+    }
+
+    # For print Rilis :
+    print "\n";
+    print "Rilis Active : $rilisCfg\n";
+
     my $file_cfg = $prefix_file_cfg . $rilisCfg. $ext_flcfg;
     my $loc_flcfg = $dir_dev.$file_cfg;
     my $locdir_pkg = $dir_dev.$pkgs_dir;
@@ -647,7 +811,7 @@ sub read_config {
     my $log_dir_rilis = $logs_dir.$rilisCfg;
 
     # Get format data config :
-    my $format_config = format_data();
+    my $format_config = format_bzr2git_config();
 
     # Check File Config :
     if (-d $dir_data_boidev) {
@@ -679,19 +843,27 @@ sub read_config {
                 $adddt_pkg->add('group' => {});
                 $adddt_pkg->add('pkgs' => {});
                 $result_adddtPkg = $adddt_pkg->as_hashref;
-                $format_config->{'pkg'} = $result_adddtPkg;
-                $data = $format_config;
+
+                my $set_pkgs = Hash::MultiValue->new(%{$format_config});
+                $set_pkgs->set('pkg' => $result_adddtPkg);
+                my $result_cfg = $set_pkgs->as_hashref;
+                $data = $result_cfg
             }
         } else {
-            BlankOnDev::Utils::file->create($file_cfg, $dir_dev, encode_json($format_config));
-#            $format_config->{'pkg'}->{'dirpkg'} = $dir_pkgrilis;
             $adddt_pkg = Hash::MultiValue->new();
             $adddt_pkg->add('dirpkg' => $dir_pkgrilis);
             $adddt_pkg->add('group' => {});
             $adddt_pkg->add('pkgs' => {});
             $result_adddtPkg = $adddt_pkg->as_hashref;
             $format_config->{'pkg'} = $result_adddtPkg;
-            $data = $format_config;
+
+            my $set_pkgs = Hash::MultiValue->new(%{$format_config});
+            $set_pkgs->set('pkg' => $result_adddtPkg);
+            my $result_cfg = $set_pkgs->as_hashref;
+            $data = $result_cfg;
+
+            BlankOnDev::Utils::file->create($file_cfg, $dir_dev, encode_json($result_cfg));
+#            $format_config->{'pkg'}->{'dirpkg'} = $dir_pkgrilis;
         }
     } else {
         mkdir($dir_data_boidev);
@@ -741,9 +913,24 @@ sub read_config {
     $r_config = $data;
     return $data;
 }
+# Subroutine for format general config :
+# ------------------------------------------------------------------------
+sub format_general_config {
+    my %data = (
+        'timezone' => '',
+        'rilis' => '',
+        'data' => {
+            'name' => '',
+            'email-git' => '',
+            'email-gpg' => '',
+            'passph-gpg' => '',
+        }
+    );
+    return \%data;
+}
 # Subroutine for format data config :
 # ------------------------------------------------------------------------
-sub format_data {
+sub format_bzr2git_config {
     my %data = (
         'timezone' => 'Asia/Makassar',
         'prepare' => 0,
@@ -768,24 +955,4 @@ sub format_data {
     );
     return \%data;
 }
-# Subroutine for list command :
-# ------------------------------------------------------------------------
-sub cmd_list {
-    my %data = ();
-
-    # Git Command :
-    $data{'git'} = {
-        'cfg-name' => 'git config --global user.name',
-        'cfg-email' => 'git config --global user.email',
-        'cfg-credential-cache' => 'git config --global credential.helper cache',
-        'cfg-creden-cache-clear' => 'git config --global --unset credential.helper',
-        'cfg-list' => 'git config --list',
-    };
-    # GPG Command :
-    $data{'gpg'} = {
-        'gen-key' => 'gpg --gen-key'
-    };
-    return \%data;
-}
-
 1;
\ No newline at end of file
